@@ -17,10 +17,10 @@ import os
 
 from google.adk.tools import ToolContext
 
+from veadk.auth.veauth.utils import get_credential_from_vefaas_iam
 from veadk.config import getenv
 from veadk.utils.logger import get_logger
 from veadk.utils.volcengine_sign import ve_request
-from veadk.auth.veauth.utils import get_credential_from_vefaas_iam
 
 logger = get_logger(__name__)
 
@@ -49,6 +49,9 @@ def run_code(
     host = getenv(
         "AGENTKIT_TOOL_HOST", service + "." + region + ".volces.com"
     )  # temporary host for code run tool
+    scheme = getenv("AGENTKIT_TOOL_SCHEME", "https", allow_false_values=True).lower()
+    if scheme not in {"http", "https"}:
+        scheme = "https"
     logger.debug(f"tools endpoint: {host}")
 
     session_id = tool_context._invocation_context.session.id
@@ -94,6 +97,7 @@ def run_code(
                     "kernel_name": language,
                 }
             ),
+            "Ttl": os.getenv("AGENTKIT_TOOL_TTL", 1800),
         },
         action="InvokeTool",
         ak=ak,
@@ -103,6 +107,7 @@ def run_code(
         region=region,
         host=host,
         header=header,
+        scheme=scheme,
     )
     logger.debug(f"Invoke run code response: {res}")
 
